#!/usr/bin/env python
from argparse import ArgumentParser
from wxskeleton.skutils import build_skeleton
import sys

def main():
    parser = ArgumentParser('Build python project skeleton at this path')
    parser.add_argument('project_name', type=str, help='project name include path')
    args = parser.parse_args()
    build_skeleton(args.project_name)
    print("Successfully build project %s!" % args.project_name)

if __name__ == "__main__":
    main()



import setuptools

config = {
    'name':'wx-skeleton',
    'version':'0.2',
    'packages':setuptools.find_packages(exclude=['tests', 'docs']),
    'entry_points':{
        'console_scripts': [
            'mkskl.py = bin.mkskl:main'
        ],
    },
    'install_requires':['nose>=1.3.7'],
    'tests_require':['nose'],
    'package_data':{
        'wxskeleton':['.gitignore']
    },
    'author':'Wang Xin',
    'author_email':'wangxin19930411@163.com',
    'description':'Quickly build python project skeleton',
    'license':'BSD',
    'url':'https://github.com/WangXin93/wx_skeleton',
}


if __name__ == "__main__":
    setuptools.setup(**config)



#!/usr/bin/env python3
import sys
import os
import shutil

gitignore_path = os.path.join(os.path.dirname(os.path.abspath((__file__))),
                              '.gitignore')

def touch(path):
    '''Create a file if it doesn't exist, otherwise update its mtime
    
    Args:
        path: string, path of file to be touched

    raise:
        NameError: if base directory doesn't exist
    '''
    assert path, "path can't be empty"
    path = os.path.expanduser(path)
    with open(path, 'a'):
        # Update mtime in case file exists
        os.utime(path, None)


def build_skeleton(project):
    # Assume project is string like "d1/a1"
    assert not os.path.exists(project), "Project path already exists"
    # Get base directory "d1"
    project_path = os.path.dirname(project)
    # Get project name "a1"
    project_name = os.path.basename(project)
    # Make project root
    os.makedirs(project)
    # mkdir bin
    os.makedirs(os.path.join(project, "bin"))
    # mkdir NAME
    os.makedirs(os.path.join(project, project_name))
    # mkdir docs
    os.makedirs(os.path.join(project, "docs"))
    # mkdir tests
    os.makedirs(os.path.join(project, "tests"))
    # touch d1/a1/a1/__init__.py
    touch(os.path.join(project, project_name, "__init__.py"))
    # touch d1/a1/tests/__init__.py
    touch(os.path.join(project, "tests", "__init__.py"))
    # touch d1/a1/bin/__init__.py
    touch(os.path.join(project, "bin", "__init__.py"))
    # touch d1/a1/setup.py
    touch(os.path.join(project, "setup.py"))
    # touch d1/a1/tests/setup_tests.py
    touch(os.path.join(project, "tests", "setup_tests.py"))
    setup_tests="""from nose.tools import *
def setup_tests():
    print("SETUP!")
"""
    with open(os.path.join(project, "tests", "setup_tests.py"), "w") as f:
        f.write(setup_tests)

    # Add .gitignore from skutils package path
    shutil.copy(gitignore_path, os.path.join(project, '.gitignore'))

    # touch d1/a1/README.md
    touch(os.path.join(project, 'README.md'))
    # Print done.
    print("Successfully run build_skeleton for %s" % project)


